.. _global_photometry:

Global Photometry
=================

Everything related to global photometry is documented bellow:

.. currentmodule:: hostphot.global_photometry
.. autofunction:: create_circular_mask
.. autofunction:: inside_galaxy
.. autofunction:: fit_2dgauss
.. autofunction:: mask_image

.. autofunction:: coadd_images
.. autofunction:: extract_aperture_params
.. autofunction:: extract_global_photometry
.. autofunction:: multi_global_photometry
